==> cfbfastR-py-0.0.7.tar.gz: cfbfastR-py-0.0.7/README.md <==
# cfbfastR-py <a href='https://cfbfastR-py.sportsdataverse.org'><img src='https://cfbfastR-py.sportsdataverse.org/img/cfbfastR-py-logo.png' align="right" height="150" /></a>
<!-- badges: start -->

![Lifecycle:experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg?style=for-the-badge&logo=github)
[![PyPI](https://img.shields.io/pypi/v/cfbfastR-py?label=cfbfastR-py&logo=python&style=for-the-badge)](https://pypi.org/project/cfbfastR-py/)
![Contributors](https://img.shields.io/github/contributors/saiemgilani/cfbfastR-py?style=for-the-badge)
[![Twitter
Follow](https://img.shields.io/twitter/follow/cfbfastR?color=blue&label=%40cfbfastR&logo=twitter&style=for-the-badge)](https://twitter.com/cfbfastR)

<!-- badges: end -->


See [CHANGELOG.md](https://cfbfastR-py.sportsdataverse.org/CHANGELOG) for details.

The goal of [cfbfastR-py](https://cfbfastR-py.sportsdataverse.org) is to provide the community with a python package for working with CFB data as a companion to the [cfbfastR](https://saiemgilani.github.io/cfbfastR) R package. Beyond data aggregation and tidying ease, one of the multitude of services that [cfbfastR-py](https://cfbfastR-py.sportsdataverse.org) provides is for benchmarking open-source expected points and win probability metrics.

## Installation

cfbfastR-py can be installed via pip:

```bash
pip install cfbfastR-py
```

or from the repo (which may at times be more up to date):

```bash
git clone https://github.com/saiemgilani/cfbfastR-py
cd cfbfastR-py
pip install -e .
```

# **Our Authors**

-   [Saiem Gilani](https://twitter.com/saiemgilani)
<a href="https://twitter.com/saiemgilani" target="blank"><img src="https://img.shields.io/twitter/follow/saiemgilani?color=blue&label=%40saiemgilani&logo=twitter&style=for-the-badge" alt="@saiemgilani" /></a>
<a href="https://github.com/saiemgilani" target="blank"><img src="https://img.shields.io/github/followers/saiemgilani?color=eee&logo=Github&style=for-the-badge" alt="@saiemgilani" /></a>


## **Citations**

To cite the [**`cfbfastR-py`**](https://cfbfastR-py.sportsdataverse.org) Python package in publications, use:

BibTex Citation
```bibtex
@misc{saiemgilani2021cfbfastRpy,
  author = {Gilani, Saiem},
  title = {cfbfastR-py: The SportsDataverse's Python Package for College Football Data.},
  url = {https://cfbfastR-py.sportsdataverse.org},
  season = {2021}
}
```

==> cfbfastR-py-0.0.26.tar.gz: cfbfastR-py-0.0.26/README.md <==
# cfbfastR-py <a href='https://cfbfastR-py.sportsdataverse.org'><img src='https://cfbfastR-py.sportsdataverse.org/img/cfbfastR-py-logo.png' align="right" height="150" /></a>
<!-- badges: start -->

![Lifecycle:experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg?style=for-the-badge&logo=github)
[![PyPI](https://img.shields.io/pypi/v/cfbfastR-py?label=cfbfastR-py&logo=python&style=for-the-badge)](https://pypi.org/project/cfbfastR-py/)
![Contributors](https://img.shields.io/github/contributors/saiemgilani/cfbfastR-py?style=for-the-badge)
[![Twitter
Follow](https://img.shields.io/twitter/follow/cfbfastR?color=blue&label=%40cfbfastR&logo=twitter&style=for-the-badge)](https://twitter.com/cfbfastR)

<!-- badges: end -->


See [CHANGELOG.md](https://cfbfastR-py.sportsdataverse.org/CHANGELOG) for details.

The goal of [cfbfastR-py](https://cfbfastR-py.sportsdataverse.org) is to provide the community with a python package for working with American Football data as a companion to the [cfbfastR](https://saiemgilani.github.io/cfbfastR) R package. Beyond data aggregation and tidying ease, one of the multitude of services that [cfbfastR-py](https://cfbfastR-py.sportsdataverse.org) provides is for benchmarking open-source expected points and win probability metrics.

## Installation

cfbfastR-py can be installed via pip:

```bash
pip install cfbfastR-py
```

or from the repo (which may at times be more up to date):

```bash
git clone https://github.com/saiemgilani/cfbfastR-py
cd cfbfastR-py
pip install -e .
```

# **Our Authors**

-   [Saiem Gilani](https://twitter.com/saiemgilani)
<a href="https://twitter.com/saiemgilani" target="blank"><img src="https://img.shields.io/twitter/follow/saiemgilani?color=blue&label=%40saiemgilani&logo=twitter&style=for-the-badge" alt="@saiemgilani" /></a>
<a href="https://github.com/saiemgilani" target="blank"><img src="https://img.shields.io/github/followers/saiemgilani?color=eee&logo=Github&style=for-the-badge" alt="@saiemgilani" /></a>


## **Citations**

To cite the [**`cfbfastR-py`**](https://cfbfastR-py.sportsdataverse.org) Python package in publications, use:

BibTex Citation
```bibtex
@misc{saiemgilani2021cfbfastRpy,
  author = {Gilani, Saiem},
  title = {cfbfastR-py: The SportsDataverse's Python Package for American Football Data.},
  url = {https://cfbfastR-py.sportsdataverse.org},
  season = {2021}
}
```
